import { Provider } from 'react-redux';
import { IntlProvider, addLocaleData } from 'react-intl';
import { getLocale } from '../locales';
import configureStore from '../store/configureStore';
import { hydrateStore } from '../actions/store';
import { fetchCustomEmojis } from '../actions/custom_emojis';
import initialState from '../initial_state';
import Compose from '../features/standalone/compose';

const { localeData, messages } = getLocale();
addLocaleData(localeData);

const store = configureStore();

if (initialState) {
  store.dispatch(hydrateStore(initialState));
}

store.dispatch(fetchCustomEmojis());

export default class TimelineContainer extends PureComponent {

  static propTypes = {
    locale: PropTypes.string.isRequired,
  };

  render () {
    const { locale } = this.props;

    return (
      <IntlProvider locale={locale} messages={messages}>
        <Provider store={store}>
          <Compose />
        </Provider>
      </IntlProvider>
    );
  }

}
